==> bacula-docs-2.4.2.tar.bz2: bacula-docs-2.4.2/home-page/fr/pages/documentation.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
    <td class="contentTopic">
      Documentation de Bacula
    </td>
  </tr>
   
  <tr>
    <td class="content">
      <ul>
        <li><a href="dev-manual/Une_breve_documentation.html">Tutorial</a>
          <br>(d&eacute;marrer ici apr&egrave;s avoir install&eacute; Bacula)
        </li>
      </ul>
    </td>
    <td class="content">
      <ul>
        <li><a href="<? echo $spath ?>/?page=news"> Actualit&eacute;s: quelles sont
          les nouveaut&eacute;s dans Bacula</a>
          <br>(changements depuis la derni&egrave;re version majeure publi&eacute;e)
        </li>
      </ul>
    </td>
  </tr>
  <tr>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="rel-manual-fr/index.html" >Manuel utilisateur (HTML)</a>
          <br>(derni&egrave;re version publi&eacute;e du manuel utilisateur)</li>
        <li><a href="<? echo $spath ?>/rel-bacula.pdf">Manuel utilisateur
          (PDF)</a>
          <br>(derni&egrave;re version publi&eacute;e du manuel utilisateur)</li>
        <li><a href="/rel-bacula-doc.tar.gz">archive du
          manuel utilisateur</a>
          <br>(derni&egrave;re version publi&eacute;e du manuel utilisateur)</li>
      </ul>
    </td>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="dev-manual/index.html" >Manuel de d&eacute;veloppement (HTML)
          </a><br>(Manuel utilisateur pour le code en cours de d&eacute;veloppement)
        </li>
        <li><a href="<? echo $spath ?>/bacula.pdf">Manuel de d&eacute;veloppement
          (PDF)</a>
          <br>(Manuel utilisateur pour le code en cours de d&eacute;veloppement)
        </li>
      </ul>
    </td>
  </tr>
  
  <tr>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="/bacula-web/index.html">Guide pour Bacula-web (Anglais)</a>
          <br>(Guide pour l'interface graphique Bacula-web)</li>
      </ul>
    </td>

    <td class="content">
      &nbsp;
      <ul>
        <li><a href="/developers/index.html">Guide du d&eacute;veloppeur (HTML - Anglais)</a>
          <br>(Guide pour les d&eacute;veloppeurs Bacula)</li>
        <li><a href="/developers.pdf">Guide du d&eacute;veloppeur
          (PDF - Anglais)</a><br>(Guide pour les d&eacute;veloppeurs Bacula)</li>
          <li><a href="<? echo $spath ?>/FLA-bacula.en.pdf">(PDF Anglis -- FLA</a>
          <br>(Fiduciary License Agreement pour les d&eacute;veloppeurs Bacula)</li>

      </ul>
    </td>
  </tr>
</table>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-3.0.0.tar.bz2: bacula-docs-3.0.0/home-page/fr/pages/documentation.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
    <td class="contentTopic">
      Documentation de Bacula
    </td>
  </tr>
   
  <tr>
    <td class="content">
      <ul>
        <li><a href="dev-manual/breve_documentation.html">Tutorial</a>
          <br>(d&eacute;marrer ici apr&egrave;s avoir install&eacute; Bacula)
        </li>
      </ul>
    </td>
    <td class="content">
      <ul>
        <li><a href="<? echo $spath ?>/?page=news"> Actualit&eacute;s: quelles sont
          les nouveaut&eacute;s dans Bacula</a>
          <br>(changements depuis la derni&egrave;re version majeure publi&eacute;e)
        </li>
      </ul>
    </td>
  </tr>
  <tr>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="rel-manual/index.html" >Manuel utilisateur (HTML)</a>
          <br>(derni&egrave;re version publi&eacute;e du manuel utilisateur)</li>
        <li><a href="<? echo $spath ?>/rel-bacula.pdf">Manuel utilisateur
          (PDF)</a>
          <br>(derni&egrave;re version publi&eacute;e du manuel utilisateur)</li>
      </ul>
    </td>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="dev-manual/index.html" >Manuel de d&eacute;veloppement (HTML)
          </a><br>(Manuel utilisateur pour le code en cours de d&eacute;veloppement)
        </li>
        <li><a href="<? echo $spath ?>/bacula.pdf">Manuel de d&eacute;veloppement
          (PDF)</a>
          <br>(Manuel utilisateur pour le code en cours de d&eacute;veloppement)
        </li>
      </ul>
    </td>
  </tr>
  
  <tr>
    <td class="content">
      &nbsp;
      <ul>
        <li><a href="/manuals/bacula-web/index.html">Guide pour Bacula-web (Anglais)</a>
          <br>(Guide pour l'interface graphique Bacula-web)</li>
      </ul>
    </td>

    <td class="content">
      &nbsp;
      <ul>
        <li><a href="/en/developers/index.html">Guide du d&eacute;veloppeur (HTML - Anglais)</a>
          <br>(Guide pour les d&eacute;veloppeurs Bacula)</li>
        <li><a href="/en/developers.pdf">Guide du d&eacute;veloppeur
          (PDF - Anglais)</a><br>(Guide pour les d&eacute;veloppeurs Bacula)</li>
          <li><a href="/en/FLA-bacula.en.pdf">(PDF Anglais -- FLA</a>
          <br>(Fiduciary License Agreement pour les d&eacute;veloppeurs Bacula)</li>

      </ul>
    </td>
  </tr>
</table>
<? require_once("inc/footer.php"); ?>
